@@ -26,6 +26,7 @@ enum class LibraryLoadHint {
     ResolveAllSymbolsHint = 0x1,
     PreventUnloadHint = 0x2,
     ExportExternalSymbolsHint = 0x4,
+    NewNameSpace = 0x8,
     DefaultHint = PreventUnloadHint,
 };
 
@@ -49,6 +50,8 @@ public:
         return reinterpret_cast<Func *>(ptr);
     }
 
+    static bool isNewNamespaceSupported();
+
 private:
     std::unique_ptr<LibraryPrivate> d_ptr;
     FCITX_DECLARE_PRIVATE(Library);
